<?php

declare(strict_types=1);

namespace Drupal\mcp\Controller;

use Drupal;
use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Cache\CacheableJsonResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\mcp\McpInterface;
use Symfony\Component\DependencyInjection\Attribute\Autowire;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for Model Context Protocol routes.
 */
final class McpController extends ControllerBase {

  public function __construct(
    #[Autowire(service: 'plugin.manager.mcp')]
    protected PluginManagerInterface $mpcPluginManager,
  ) {}

  /**
   * Route for get required data when mcp-server-drupal is initialized.
   */
  public function init(): CacheableJsonResponse {
    $tools = [];
    foreach ($this->mpcPluginManager->getDefinitions() as $id => $value) {
      $instance = $this->mpcPluginManager->createInstance($id);
      if (!$instance instanceof McpInterface) {
        continue;
      }

      $definitionTools = $instance->getTools();
      foreach ($definitionTools as $tool) {
        $tools[] = $tool;
      }
    }

    return new CacheableJsonResponse([
      'tools' => $tools,
    ]);
  }

  public function toolsExecute(string $toolId, Request $request): CacheableJsonResponse {
    [$definitionId, $pluginId] = explode('_', $toolId);
    $instance = $this->mpcPluginManager->createInstance($definitionId);

    if (!$instance instanceof McpInterface) {
      return new CacheableJsonResponse([
        'message' => 'Tool not found',
      ]);
    }
    $arguments = json_decode($request->getContent(), TRUE);
    $result = $instance->execute($pluginId, $arguments);


    return new CacheableJsonResponse([
      'result' => $result,
    ]);
  }

}
