<?php

declare(strict_types=1);

namespace Drupal\mcp\Plugin\Mcp;

use Drupal;
use Drupal\mcp\Attribute\Mcp;
use Drupal\mcp\McpPluginBase;
use Drupal\mcp\Tool;
use InvalidArgumentException;
use stdClass;

/**
 * Plugin implementation of the mcp.
 */
#[Mcp(
  id: 'general'
)]
final class General extends McpPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getTools(): array {
    return [
      new Tool(
        name: $this->getPluginId().'_info',
        description: 'Returns information about the site.',
        inputSchema: [
          'type'       => 'object',
          'properties' => new stdClass(),
        ]
      ),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function execute(string $toolId, mixed $arguments): array {
    if ($toolId === 'info') {
      return [
        'siteName'   => $this->configFactory->get('system.site')->get('name'),
        'siteSlogan' => $this->configFactory->get('system.site')->get('slogan'),
        'version'    => Drupal::VERSION,
      ];
    }

    throw new InvalidArgumentException('Tool not found');
  }

}
